==> haskell-tree-diff-0.3.0.1-220.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tree-diff
version:              0.3.0.1
visibility:           public
id:                   tree-diff-0.3.0.1-AkUKEmzEwHULaFfJNgK0TG
key:                  tree-diff-0.3.0.1-AkUKEmzEwHULaFfJNgK0TG
license:              GPL-2.0-or-later
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/tree-diff
synopsis:             Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:

    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @

    This package works on trees.

    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @

    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.

    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.

    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    \  {fooBool = [-True, +False, False, +True],
    \   fooInt = 42,
    \   fooString = -"old" +"new"}
    @

category:             Data, Testing
abi:                  0039259540f5b066368fed68e7dd06c6
exposed:              True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.OMap
    Data.TreeDiff.Parser Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck
    Data.TreeDiff.Tree

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tree-diff-0.3.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tree-diff-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tree-diff-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tree-diff
hs-libraries:         HStree-diff-0.3.0.1-AkUKEmzEwHULaFfJNgK0TG
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    ansi-terminal-1.0.2-99kMoKqjfKvAwKECL4LpDt
    ansi-wl-pprint-1.0.2-7sOIeOs5AP2BbbQYEAm2uX base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z parsec-3.1.16.1
    parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT pretty-1.1.3.6
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV
    semialign-1.3.1-H4mxDRs3fr5J5cBeCN8OlQ
    strict-0.5.1-Kvxonrthq62FwakQ5ElNMl
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    these-1.2.1-FiiqKcU92mLD4q4YanLE50 time-1.12.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-types-1.0.6-58FfeLal0FhHrTZjsfHNqD
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html:         /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tree-diff-0.3.0.1-221-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tree-diff
version:              0.3.0.1
visibility:           public
id:                   tree-diff-0.3.0.1-FOdqI31cYKrGUBA6w1LrTp
key:                  tree-diff-0.3.0.1-FOdqI31cYKrGUBA6w1LrTp
license:              GPL-2.0-or-later
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/tree-diff
synopsis:             Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:

    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @

    This package works on trees.

    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @

    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.

    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.

    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    \  {fooBool = [-True, +False, False, +True],
    \   fooInt = 42,
    \   fooString = -"old" +"new"}
    @

category:             Data, Testing
abi:                  8b9cd8a51b5febaa5e8156b4d647d3dd
exposed:              True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.OMap
    Data.TreeDiff.Parser Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck
    Data.TreeDiff.Tree

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tree-diff-0.3.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tree-diff-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tree-diff-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tree-diff
hs-libraries:         HStree-diff-0.3.0.1-FOdqI31cYKrGUBA6w1LrTp
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    ansi-terminal-1.0.2-8AlL5ra8Vsx5bOLC8RDvPh
    ansi-wl-pprint-1.0.2-6wF9D8KNkfn6IyWIcVecCI base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    containers-0.6.7 deepseq-1.4.8.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD parsec-3.1.16.1
    parsers-0.12.12-PO1r5WusBRCqoNlSszPjk pretty-1.1.3.6
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW
    semialign-1.3.1-ds4uro8cXRHYHfeRBsHPF
    strict-0.5.1-FbuUXvHHt04IVZ1UpYOqLR
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    these-1.2.1-FFxH0GxUZUDAtgQSChMM1W time-1.12.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uuid-types-1.0.6-21TzNsexUnW19QIZkyQGNe
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html:         /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
